const GLib = imports.gi.GLib;
const Gio = imports.gi.Gio;
const St = imports.gi.St;
const Main = imports.ui.main;
const PanelMenu = imports.ui.panelMenu;
const PopupMenu = imports.ui.popupMenu;
const Util = imports.misc.util;
const Lang = imports.lang;

let BOOSTED = false;

const VolumeBooster = new Lang.Class({
  Name: "VolumeBooster",
  Extends: PanelMenu.Button,

  _init: function () {
    this.parent(1, "VolumeBooster", false);

    let box = new St.BoxLayout({ style_class: "panel-status-menu-box" });

    this.icon = new St.Icon({
      icon_name: "emblem-music-symbolic",
      style_class: "custom-icon",
    });
    box.add(this.icon);
    this.actor.add_child(box);
    this._buildMenu();
  },

  destroy: function () {
    this.parent();
  },

  _buildMenu: function () {
    let that = this;

    that.customMenuItem = new PopupMenu.PopupSwitchMenuItem(
      _("Boost Volume"),
      BOOSTED,
      { reactive: true }
    );

    //start

    let [res, pid, in_fd, out_fd, err_fd] = GLib.spawn_async_with_pipes(
      null,
      ["pactl", "list", "sinks"],
      null,
      GLib.SpawnFlags.SEARCH_PATH,
      null
    );

    let out_reader = new Gio.DataInputStream({
      base_stream: new Gio.UnixInputStream({ fd: out_fd }),
    });

    for (let ee = 0; ee < 9; ee++) {
      out_reader.read_line(null);
    }
    let [out, size] = out_reader.read_line(null);

    let ss = out.toString();

    ss = ss.split(" ");

    out = ss[4];
    out = out.substring(0, out.length - 1);

    if (out_fd == null) {
    } else {
      def = out;
      if (out > 160) {
        that.customMenuItem._switch.state = true;

        that.icon.add_style_class_name("boosted");
      } else {
        that.customMenuItem._switch.state = false;

        that.icon.remove_style_class_name("boosted");
      }
    }

    that.customMenuItem.connect("toggled", Lang.bind(that, that._onToggle));

    //end

    that.menu.addMenuItem(that.customMenuItem);
  },

  _onToggle: function () {
    BOOSTED = this.customMenuItem.state;
    if (!BOOSTED) {
      Util.spawn(["pactl", "--", "set-sink-volume", "1", "150%"]);
      this.icon.remove_style_class_name("boosted");
    } else {
      Util.spawn(["pactl", "--", "set-sink-volume", "1", "200%"]);
      this.icon.add_style_class_name("boosted");
    }
  },
});

let volumeBooster;

function init() {}

function enable() {
  volumeBooster = new VolumeBooster();
  Main.panel.addToStatusArea("VolumeBooster", volumeBooster, 1);
}

function disable() {}
